@@ -1,11 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "autocorrection/widgets/lineeditwithautocorrection.h"
-#include "autocorrection/autocorrection.h"
+#include <PimCommonAutoCorrection/AutoCorrection>
 
 #include <QKeyEvent>
 
@@ -14,7 +14,7 @@ class PimCommon::LineEditWithAutoCorrectionPrivate
 {
 public:
     LineEditWithAutoCorrectionPrivate()
-        : mAutoCorrection(new PimCommon::AutoCorrection())
+        : mAutoCorrection(new PimCommonAutoCorrection::AutoCorrection())
     {
     }
 
@@ -25,7 +25,7 @@ public:
         }
     }
 
-    PimCommon::AutoCorrection *mAutoCorrection = nullptr;
+    PimCommonAutoCorrection::AutoCorrection *mAutoCorrection = nullptr;
     bool mNeedToDeleteAutoCorrection = true;
 };
 
@@ -35,17 +35,14 @@ LineEditWithAutoCorrection::LineEditWithAutoCorrection(QWidget *parent, const QS
 {
 }
 
-LineEditWithAutoCorrection::~LineEditWithAutoCorrection()
-{
-    delete d;
-}
+LineEditWithAutoCorrection::~LineEditWithAutoCorrection() = default;
 
-AutoCorrection *LineEditWithAutoCorrection::autocorrection() const
+PimCommonAutoCorrection::AutoCorrection *LineEditWithAutoCorrection::autocorrection() const
 {
     return d->mAutoCorrection;
 }
 
-void LineEditWithAutoCorrection::setAutocorrection(PimCommon::AutoCorrection *autocorrect)
+void LineEditWithAutoCorrection::setAutocorrection(PimCommonAutoCorrection::AutoCorrection *autocorrect)
 {
     d->mNeedToDeleteAutoCorrection = false;
     delete d->mAutoCorrection;
@@ -54,16 +51,18 @@ void LineEditWithAutoCorrection::setAutocorrection(PimCommon::AutoCorrection *au
 
 void LineEditWithAutoCorrection::setAutocorrectionLanguage(const QString &language)
 {
-    d->mAutoCorrection->setLanguage(language);
+    PimCommonAutoCorrection::AutoCorrectionSettings *settings = d->mAutoCorrection->autoCorrectionSettings();
+    settings->setLanguage(language);
+    d->mAutoCorrection->setAutoCorrectionSettings(settings);
 }
 
 void LineEditWithAutoCorrection::keyPressEvent(QKeyEvent *e)
 {
-    if (d->mAutoCorrection && d->mAutoCorrection->isEnabledAutoCorrection()) {
+    if (d->mAutoCorrection && d->mAutoCorrection->autoCorrectionSettings()->isEnabledAutoCorrection()) {
         if ((e->key() == Qt::Key_Space) || (e->key() == Qt::Key_Enter) || (e->key() == Qt::Key_Return)) {
             if (!textCursor().hasSelection()) {
-                // no Html format in subject.
                 int position = textCursor().position();
+                // no Html format in subject. => false
                 const bool addSpace = d->mAutoCorrection->autocorrect(false, *document(), position);
                 QTextCursor cur = textCursor();
                 cur.setPosition(position);
